package com.gic.haoban.manage.web.controller;


import java.util.List;

import org.apache.commons.lang3.StringUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;

import com.gic.haoban.common.utils.HaobanResponse;
import com.gic.haoban.manage.api.dto.MaterialCategoryDTO;
import com.gic.haoban.manage.api.dto.MaterialDTO;
import com.gic.haoban.manage.api.service.MaterialApiService;
import com.gic.haoban.manage.web.errCode.HaoBanErrCode;

@RestController
public class MaterialController extends WebBaseController{
	
	@Autowired
	private MaterialApiService materialApiService;
	
	/**
     * 素材分组新增
     * @return
     */
    @RequestMapping("/mateial-add-category")
    public HaobanResponse materialAddCategory(MaterialCategoryDTO materialCategoryDTO) {
		String categoryName  = materialCategoryDTO.getCategoryName();
		String categoryParentId = materialCategoryDTO.getCategoryParentId();
		if(StringUtils.isAnyBlank(categoryParentId,categoryName)){
			return resultResponse(HaoBanErrCode.ERR_2);
		}
		boolean flag = materialApiService.hasCategoryNameExsit(categoryName,categoryParentId,null);
		if(flag){
			return resultResponse(HaoBanErrCode.ERR_10015);
		}
		materialApiService.insertCategory(materialCategoryDTO);
    	return resultResponse(HaoBanErrCode.ERR_1);
    }
	
	/**
     * 素材分组查询
     * @return
     */
    @RequestMapping("/category-list")
    public HaobanResponse categoryList(String wxEnterpriseId) {
		List<MaterialCategoryDTO> list = materialApiService.listCategory(wxEnterpriseId);
    	return resultResponse(HaoBanErrCode.ERR_1,list);
    }
	
	/**
     * 素材分组修改
     * @return
     */
    @RequestMapping("/category-edit")
    public HaobanResponse categoryEdit(MaterialCategoryDTO materialCategoryDTO) {
		String categoryName  = materialCategoryDTO.getCategoryName();
		String categoryId = materialCategoryDTO.getCategoryId();
		if(StringUtils.isAnyBlank(categoryName,categoryId)){
			return resultResponse(HaoBanErrCode.ERR_2);
		}
		MaterialCategoryDTO dto = materialApiService.selectMaterialCategoryById(categoryId);
		if(dto == null){
			return resultResponse(HaoBanErrCode.ERR_10016);
		}
		String categoryParentId = dto.getCategoryParentId();
		boolean flag = materialApiService.hasCategoryNameExsit(categoryName,categoryParentId,materialCategoryDTO.getCategoryId());
		if(flag){
			return resultResponse(HaoBanErrCode.ERR_10015);
		}
		materialApiService.editCategory(materialCategoryDTO);
    	return resultResponse(HaoBanErrCode.ERR_1);
    }
    
    
    /**
     * 素材分组删除
     * @return
     */
    @RequestMapping("/category-del")
    public HaobanResponse categoryDel(String categoryId) {
    	MaterialCategoryDTO dto = materialApiService.selectMaterialCategoryById(categoryId);
		if(dto == null){
			return resultResponse(HaoBanErrCode.ERR_10016);
		}
		List<MaterialDTO> list = materialApiService.listMaterialByCategoryId(categoryId);
		if(!list.isEmpty()){
			return resultResponse(HaoBanErrCode.ERR_10017);
		}
		dto.setStatusFlag(0);
		materialApiService.editCategory(dto);
    	return resultResponse(HaoBanErrCode.ERR_1);
    }


}
